summaryrefslogtreecommitdiffstats
path: root/parameter/InstanceConfigurableElement.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /parameter/InstanceConfigurableElement.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'parameter/InstanceConfigurableElement.h')
-rw-r--r--parameter/InstanceConfigurableElement.h23
1 files changed, 13 insertions, 10 deletions
diff --git a/parameter/InstanceConfigurableElement.h b/parameter/InstanceConfigurableElement.h
index 39a0d94..b3cdf62 100644
--- a/parameter/InstanceConfigurableElement.h
+++ b/parameter/InstanceConfigurableElement.h
@@ -32,6 +32,9 @@
#include "ConfigurableElementWithMapping.h"
#include "TypeElement.h"
+#include <list>
+#include <string>
+
class IMapper;
class CParameterBlackboard;
class CParameterAccessContext;
@@ -48,23 +51,23 @@ public:
EComponent
};
- CInstanceConfigurableElement(const string& strName, const CTypeElement* pTypeElement);
+ CInstanceConfigurableElement(const std::string& strName, const CTypeElement* pTypeElement);
// Instantiated type
const CTypeElement* getTypeElement() const;
- virtual bool getMappingData(const string& strKey, const string*& pStrValue) const;
+ virtual bool getMappingData(const std::string& strKey, const std::string*& pStrValue) const;
/**
* Returns the mapping data associated to the type element of the current
* InstanceConfigurableElement, as a formatted string
*
* @return A string containing the formatted mapping
*/
- string getFormattedMapping() const;
+ std::string getFormattedMapping() const;
// From CElement
- virtual string getKind() const;
+ virtual std::string getKind() const;
// Syncer to/from HW
void setSyncer(ISyncer* pSyncer);
@@ -74,10 +77,10 @@ public:
virtual Type getType() const = 0;
// Mapping execution
- bool map(IMapper& mapper, string& strError);
+ bool map(IMapper& mapper, std::string& strError);
// Element properties
- virtual void showProperties(string& strResult) const;
+ virtual void showProperties(std::string& strResult) const;
// Scalar or Array?
bool isScalar() const;
@@ -88,7 +91,7 @@ public:
/**
* Get the list of all the ancestors that have a mapping.
*
* The mapping is represented as a string of all the mapping data (key:value) defined in the
* context of the element.
* In this class, the method is generic and calls its parent getListOfElementsWithMappings(...)
* method.
@@ -97,7 +100,7 @@ public:
* that have a mapping. Elements are added at the end of the list, so the root Element will be
* the last one.
*/
- virtual void getListOfElementsWithMapping(list<const CConfigurableElement*>&
+ virtual void getListOfElementsWithMapping(std::list<const CConfigurableElement*>&
configurableElementPath) const;
protected:
// Syncer
@@ -48,23 +51,23 @@ public:
/**
* Returns the mapping data associated to the type element of the current
- * InstanceConfigurableElement, as a formatted string
+ * InstanceConfigurableElement, as a formatted std::string
*
@@ -48,23 +51,23 @@ public:
*
- * @return A string containing the formatted mapping
+ * @return A std::string containing the formatted mapping
*/
@@ -88,7 +91,7 @@ public:
* Get the list of all the ancestors that have a mapping.
*
- * The mapping is represented as a string of all the mapping data (key:value) defined in the
+ * The mapping is represented as a std::string of all the mapping data (key:value) defined in the
* context of the element.
* In this class, the method is generic and calls its parent getListOfElementsWithMappings(...)